==> haskell-http-types-0.12.4-12-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-types
version:              0.12.4
visibility:           public
id:                   http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
key:                  http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
license:              BSD-3-Clause
copyright:            (C) 2011 Aristid Breitkreuz
maintainer:           felix.paulusma@gmail.com
author:               Aristid Breitkreuz, Michael Snoyman
homepage:             https://github.com/Vlix/http-types
synopsis:
    Generic HTTP types for Haskell (for both client and server code).

description:
    Types and functions to describe and handle HTTP concepts.
    Including "methods", "headers", "query strings", "paths" and "HTTP versions".

category:             Network, Web
abi:                  c01321da18cc5c690ab7d083f39aadd6
exposed:              True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-types-0.12.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-types-0.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-types
hs-libraries:         HShttp-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html:         /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.12.4-55.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-types
version:              0.12.4
visibility:           public
id:                   http-types-0.12.4-1mXIbLxCpEKp4Jrjs0euO
key:                  http-types-0.12.4-1mXIbLxCpEKp4Jrjs0euO
license:              BSD-3-Clause
copyright:            (C) 2011 Aristid Breitkreuz
maintainer:           felix.paulusma@gmail.com
author:               Aristid Breitkreuz, Michael Snoyman
homepage:             https://github.com/Vlix/http-types
synopsis:
    Generic HTTP types for Haskell (for both client and server code).

description:
    Types and functions to describe and handle HTTP concepts.
    Including "methods", "headers", "query strings", "paths" and "HTTP versions".

category:             Network, Web
abi:                  ab5638d95e5aaa68e80a5a00187c4266
exposed:              True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-types
hs-libraries:         HShttp-types-0.12.4-1mXIbLxCpEKp4Jrjs0euO
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-ADYWB5NR7iSCpUfBs08sXI text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html:         /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
